.. AUTO-GENERATED FILE -- DO NOT EDIT!

Module: :mod:`viewer.utils`
===========================
.. automodule:: skimage.viewer.utils

.. currentmodule:: skimage.viewer.utils
.. autosummary::

   skimage.viewer.utils.figimage
   skimage.viewer.utils.init_qtapp
   skimage.viewer.utils.new_plot
   skimage.viewer.utils.start_qtapp
   skimage.viewer.utils.update_axes_image

   skimage.viewer.utils.ClearColormap
   skimage.viewer.utils.FigureCanvas
   skimage.viewer.utils.LinearColormap
   skimage.viewer.utils.RequiredAttr

    skimage.viewer.utils.canvas
    skimage.viewer.utils.core
    skimage.viewer.utils.dialogs

figimage
--------

.. autofunction:: skimage.viewer.utils.figimage


.. include:: skimage.viewer.utils.figimage.examples

init_qtapp
----------

.. autofunction:: skimage.viewer.utils.init_qtapp


.. include:: skimage.viewer.utils.init_qtapp.examples

new_plot
--------

.. autofunction:: skimage.viewer.utils.new_plot


.. include:: skimage.viewer.utils.new_plot.examples

start_qtapp
-----------

.. autofunction:: skimage.viewer.utils.start_qtapp


.. include:: skimage.viewer.utils.start_qtapp.examples

update_axes_image
-----------------

.. autofunction:: skimage.viewer.utils.update_axes_image


.. include:: skimage.viewer.utils.update_axes_image.examples


:class:`ClearColormap`
----------------------


.. autoclass:: ClearColormap
  :members:
  :undoc-members:
  :show-inheritance:

  .. automethod:: __init__

.. include:: skimage.viewer.utils.ClearColormap.examples


:class:`FigureCanvas`
---------------------


.. autoclass:: FigureCanvas
  :members:
  :undoc-members:
  :show-inheritance:

  .. automethod:: __init__

.. include:: skimage.viewer.utils.FigureCanvas.examples


:class:`LinearColormap`
-----------------------


.. autoclass:: LinearColormap
  :members:
  :undoc-members:
  :show-inheritance:

  .. automethod:: __init__

.. include:: skimage.viewer.utils.LinearColormap.examples


:class:`RequiredAttr`
---------------------


.. autoclass:: RequiredAttr
  :members:
  :undoc-members:
  :show-inheritance:

  .. automethod:: __init__

.. include:: skimage.viewer.utils.RequiredAttr.examples

